package Ogre::Entity;

use strict;
use warnings;

use Ogre::MovableObject;
our @ISA = qw(Ogre::MovableObject);   # Ogre::Resource::Listener


1;
